@@ -1,8 +1,9 @@
 package Encode::IBM;
-our $VERSION = '0.02';
+our $VERSION = '0.04';
  
 use Encode;
 use XSLoader;
+use Encode::IBM::947SOSI;
 XSLoader::load(__PACKAGE__,$VERSION);
 
 1;
@@ -14,14 +15,15 @@ Encode::IBM - IBM-specific encoding mappings
 
 =head1 VERSION
 
-This document describes version 0.02 of Encode::IBM, released
-December 30, 2004.
+This document describes version 0.04 of Encode::IBM, released
+September 16, 2006.
  
 =head1 SYNOPSIS
 
     use Encode;
     use Encode::IBM;
-    binmode( STDIN, 'ibm-947' );
+    binmode( STDIN, ':encoding(ibm-835)' );
+    binmode( STDOUT, ':encoding(ibm-947-sosi)' );
 
 =head1 SEE ALSO
 
